#
# spec file for package python-django-health-check
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-health-check
Version:        3.18.3
Release:        1.2
Summary:        Run checks on Django and is dependent services
License:        MIT
URL:            https://github.com/revsys/django-health-check
Source:         https://github.com/revsys/django-health-check/archive/%{version}.tar.gz#/django-health-check-%{version}.tar.gz
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module celery}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module redis}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
# Additional test requirements
BuildRequires:  %{python_module django-storages}
BuildRequires:  %{python_module boto3}
#
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.11
BuildArch:      noarch
%python_subpackages

%description
This project checks for various conditions and provides reports when anomalous
behavior is detected.

Services checked include databases, caches, queue servers, celery processes, etc.

%prep
%autosetup -p1 -n django-health-check-%{version}
# setuptools-scm fails for GitHub archives
sed -i 's/use_scm_version=True/version="%{version}"/' setup.py

# Hot fix: include sub-packages (and a template in %%install)
# https://github.com/KristianOellegaard/django-health-check/issues/268
sed -i 's/packages = health_check/packages = find:/' setup.cfg

# do not nedlessly pull extra deps
sed -i -e '/sphinx/d;/pytest-runner/d;/--cov[-=]/d' setup.cfg

%build
%pyproject_wheel

%install
%pyproject_install
%{python_expand # https://github.com/KristianOellegaard/django-health-check/issues/268
rm -rf %{buildroot}%{$python_sitelib}/tests/
if [[ -f %{buildroot}%{$python_sitelib}/health_check/templates/health_check/index.html ]]; then false; fi
ls %{buildroot}%{$python_sitelib}/health_check/cache/
mkdir -p %{buildroot}%{$python_sitelib}/health_check/templates/health_check
cp health_check/templates/health_check/index.html %{buildroot}%{$python_sitelib}/health_check/templates/health_check
%fdupes %{buildroot}%{$python_sitelib}
}

%check
rm -rf /tmp/testenv
mkdir /tmp/testenv
mv tests /tmp/testenv
cd /tmp/testenv
PYTHONPATH=${PWD}
export DJANGO_SETTINGS_MODULE=tests.testapp.settings
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/health_check
%{python_sitelib}/django_health_check-%{version}.dist-info

%changelog
* Tue Nov 12 2024 Dirk Müller <dmueller@suse.com>
- update to 3.18.3:
  * Drop deprecated DEFAULT_FILE_STORAGE setting usage
* Sat May  4 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Update to 3.18.2
  * Jump multiple versions, reference upstream changelog
- Drop python-django-health-check-no-mock.patch (solved upstream)
- Build with sle15_python_module_pythons for modern Python on Leap
* Thu Feb 22 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pyproject macros.
* Mon May  9 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/KristianOellegaard/django-health-check/issues/323
  + python-django-health-check-no-mock.patch
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Use django-codemod to finish Django 4 compatibility
- Update to 3.16.5
  * Fix default_app_config RemovedInDjango41Warning warning
  * Fix Django 4 Exception 'never_cache didn't receive an HttpRequest'
- from v3.16.4
  * Add default_auto_field to satisfy Django 4.0
- from v3.16.2
  * Fix text alignment for time column in Safari
- from v3.16.1
  * Fix Celery ping health check functionality with multiple workers
- from v3.16.0
  * Add second celery health chat that uses ping instead of executing a task
- from v3.15.0
  * Split celery timeout into two separate settings
- from v3.14.3
  * Use default cache timeout instead of 1s
- from v3.14.2
  * Resolve Django 4.0 deprecation warnings
- from v3.14.1
  * Revert "Clean results task Health Check"
* Thu Sep 17 2020 John Vandenberg <jayvdb@gmail.com>
- Workaround upstream packaging problem omitting sub-packages
  and templates
* Thu Sep 17 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v3.14.0
  * Register health check for each cache configuration
- from v3.13.2
  * Add backend checking if all migrations are applied
- from v3.12.2
  * Close all (even non default) db connections after check suite
* Wed Sep  2 2020 Marketa Calabkova <mcalabkova@suse.com>
- Fix test execution
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.12.1:
  * Add health_check Django command (CLI) (#217, #234)
* Tue Nov  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.11.1:
  * Resolve #232 -- Change license information to MIT
* Tue Oct 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, will be needed by ara
